[![Build Status](https://secure.travis-ci.org/clusto/clusto.png)](http://travis-ci.org/clusto/clusto)


What is Clusto?
---------------

Clusto is a cluster management tool.  It helps you keep track of your
inventory, where it is, how it's connected, and provides an abstracted
interface for interacting with the elements of the infrastructure.

Some docs are available under docs/ and there are more code examples in the
unit tests in src/clusto/test/.


